/*
    libut61 - library for parsing UT61 (ES51922) DMM readout data stream
    Copyright (C) 2021  Tibor 'Igor2' Palinkas

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    Project page:           http://www.repo.hu/projects/ut61
    Version control:        svn://svn.repo.hu/ut61/trunk
    Contact (email & IRC):  http://igor2.repo.hu/contact.html
*/

#ifndef UT61_H
#define UT61_H

#define UT61_VER_MAJOR 1
#define UT61_VER_MINOR 0
#define UT61_VER_PATCH 0

extern int ut61_verbose;

typedef struct {
	/* digested, high level, human readable */
	double value;      /* currently measured value (hold doesn't apply) */
	char value_str[8]; /* human readable string, as displayed on the LCD, without unit */
	const char *unit;  /* unit for value */

	double base_value;     /* currently measured value in base unit */
	double base_vmax;      /* maximum value in this range (base unit) */
	const char *base_unit; /* unit for base_value */

	const char *func_name; /* human readable name of the function mode the DMM is in */
	const char *info;      /* human readable info on the validity of the value; e.g. ol, ul, batt; 'ok' if everything is fine */

	char dig_left;         /* number of digits left to the decimal point (1..4) */
	char dig_right;        /* number of digits right to the decimal point (1..4) */

	/* packet and communication state */
	unsigned valid:1;
	unsigned raw_valid:1;
	unsigned synced:1; /* last message parsed correctly on the low level; if 0, need to start with a sync */

	/* raw */
	unsigned judge:1;
	unsigned sign:1;
	unsigned batt:1;
	unsigned ol:1;
	unsigned max:1;
	unsigned min:1;
	unsigned rel:1;
	unsigned rmr:1;
	unsigned ul:1;
	unsigned pmax:1;
	unsigned pmin:1;
	unsigned dc:1;
	unsigned ac:1;
	unsigned automatic:1;
	unsigned vahz:1;
	unsigned vbar:1;
	unsigned hold:1;
	unsigned lpf:1;
	int func;
	int range, dig[5];
} ut61_packet_t;

#endif
